RESOURCE_NAME = 'out'

CONFIG_URL = 'source.path'
CONFIG_FORMAT = 'source.format'
CONFIG_FORMAT_ = (CONFIG_FORMAT, 'File Format')
CONFIG_ENCODING = 'source.encoding'
CONFIG_HEADERS = 'source.headers'
CONFIG_SHEET = 'source.sheet'
CONFIG_SHEET_NAMES = 'source.sheet_names'
CONFIG_FORCE_STRINGS = 'source.force_strings'
CONFIG_JSON_PROPERTY = 'source.property'

CONFIG_SKIP_ROWS = 'structure.skip_rows'
CONFIG_SKIP_COLS = 'structure.skip_cols'
CONFIG_HEADER_COUNT = 'structure.header_count'
CONFIG_HEADER_FIELDS = 'structure.headers'

CONFIG_TAXONOMY_LIST = 'taxonomy.options'
CONFIG_TAXONOMY_ID = 'taxonomy.id'
CONFIG_TAXONOMY_CT = 'taxonomy.columnTypes'
CONFIG_TAXONOMY_SETTINGS = 'taxonomy.settings'

CONFIG_CONSTANTS = 'constants'

CONFIG_MODEL_MAPPING = 'model.mapping'
CONFIG_MODEL_EXTRA_FIELDS = 'model.extraFields'
CONFIG_PRIMARY_KEY = 'model.primary_key'

CONFIG_PUBLISH_ALLOWED = 'publish.allowed'
